http
=================================================

.. versionadded:: 1.1.0

.. automodule:: smisk.mvc.http
  :members:
  :undoc-members:


Status codes
---------------------------------------

.. attribute:: Continue

  HTTP status 100

.. attribute:: SwitchingProtocols

  HTTP status 101

.. attribute:: OK

  HTTP status 200

.. attribute:: Created

  HTTP status 201

.. attribute:: Accepted

  HTTP status 202

.. attribute:: NonAuthoritativeInformation

  HTTP status 203

.. attribute:: NoContent

  HTTP status 204

.. attribute:: ResetContent

  HTTP status 205

.. attribute:: PartialContent

  HTTP status 206

.. attribute:: MultipleChoices

  HTTP status 300

.. attribute:: MovedPermanently

  HTTP status 301

.. attribute:: Found

  HTTP status 302

.. attribute:: SeeOther

  HTTP status 303

.. attribute:: NotModified

  HTTP status 304

.. attribute:: UseProxy

  HTTP status 305

.. attribute:: TemporaryRedirect

  HTTP status 307

.. attribute:: BadRequest

  HTTP status 400

.. attribute:: Unauthorized

  HTTP status 401

.. attribute:: PaymentRequired

  HTTP status 402

.. attribute:: Forbidden

  HTTP status 403

.. attribute:: NotFound

  HTTP status 404

.. attribute:: ControllerNotFound

  HTTP status 404

.. attribute:: MethodNotFound

  HTTP status 404

.. attribute:: TemplateNotFound

  HTTP status 404

.. attribute:: MethodNotAllowed

  HTTP status 405

.. attribute:: NotAcceptable

  HTTP status 406

.. attribute:: ProxyAuthenticationRequired

  HTTP status 407

.. attribute:: RequestTimeout

  HTTP status 408

.. attribute:: Conflict

  HTTP status 409

.. attribute:: Gone

  HTTP status 410

.. attribute:: LengthRequired

  HTTP status 411

.. attribute:: PreconditionFailed

  HTTP status 412

.. attribute:: RequestEntityTooLarge

  HTTP status 413

.. attribute:: RequestURITooLarge

  HTTP status 414

.. attribute:: UnsupportedMediaType

  HTTP status 415

.. attribute:: RequestedRangeNotSatisfiable

  HTTP status 416

.. attribute:: ExpectationFailed

  HTTP status 417

.. attribute:: InternalServerError

  HTTP status 500

.. attribute:: NotImplemented

  HTTP status 501

.. attribute:: BadGateway

  HTTP status 502

.. attribute:: ServiceUnavailable

  HTTP status 503

.. attribute:: GatewayTimeout

  HTTP status 504

.. attribute:: HTTPVersionNotSupported

  HTTP status 505
